@@ -1,5 +1,4 @@
-def add(a,b):
-    return a+b
+
 import pandas as pd 
 import re ,spacy
 import coreferee
